@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Class::MOP;
 use Fey::Meta::Class::Table;
@@ -16,9 +16,10 @@ use Moose::Util::MetaRole;
 use MooseX::Params::Validate qw( pos_validated_list );
 
 Moose::Exporter->setup_import_methods(
-    with_meta => [qw( has_table has_policy has_one has_many transform )],
-    as_is     => [qw( inflate deflate handles )],
-    also      => 'Moose'
+    with_meta =>
+        [qw( has_table has_policy has_one has_many transform query )],
+    as_is => [qw( inflate deflate handles )],
+    also  => 'Moose'
 );
 
 sub init_meta {
@@ -116,6 +117,13 @@ sub has_many {
     $meta->add_has_many(%p);
 }
 
+sub query {
+    my $meta = shift;
+    my $name = shift;
+
+    $meta->add_query_method( name => $name, @_ );
+}
+
 1;
 
 __END__
@@ -277,6 +285,12 @@ You can also specify an C<order_by> parameter as an array
 reference. This should be an array like you would pass to C<<
 Fey::SQL::Select->order_by() >>.
 
+=head2 query $name => select => $select, bind_params => sub { ... }
+
+The C<query()> function declares a method based on the given query. This works
+much like declaring an attribute with the C<FromSelect> metaclass, but the
+value returned from the query is not stored in the object.
+
 =head2 transform $column1, $column2 => inflate { ... } => deflate { ... }
 
 The C<transform()> function declares an inflator, deflator, or both
